@@ -267,7 +267,7 @@ class cmnConfig(cmnConfigBase):
         """
         return 'LibHanger.ini'
     
-    def getConfig(self, _scriptFilePath: str, configFileDir: str = ''):
+    def getConfig(self, _scriptFilePath: str, configFileDir: str = '', baseConfigFile: str = ''):
 
         """ 
         設定ファイルを読み込む 
@@ -295,8 +295,9 @@ class cmnConfig(cmnConfigBase):
         self.scriptFilePath = _scriptFilePath
         
         # スクリプトファイルの場所から見たiniファイル相対パス取得
-        iniFileDirPath = self.getConfigFileName() \
-            if configFileDir == '' else os.path.join(configFileDir, self.getConfigFileName())
+        configFileName = self.getConfigFileName() if baseConfigFile == '' else baseConfigFile
+        iniFileDirPath = configFileName \
+            if configFileDir == '' else os.path.join(configFileDir, configFileName)
         # スクリプトファイルの絶対パス取得
         iniScriptPathAbs = pathlib.Path(os.path.abspath(os.path.dirname(_scriptFilePath)))
         # iniファイルパス取得
