@@ -3,12 +3,15 @@ import psutil
 def getDiskUsage():
     
     """
-    空きディスク容量(%)
+    ディスク使用量(%)
     """
     
     disk = psutil.disk_usage('/')
     
     return disk.percent
 
-# 空きディスク容量
+# ディスク使用量(%)
 dskUsage = getDiskUsage()
+
+# ディスク空き容量(%)
+dskFree = 100 - dskUsage
\ No newline at end of file
