@@ -6,8 +6,7 @@ from typing import TypeVar, Generic
 from enum import Enum
 from sqlalchemy.exc import SQLAlchemyError
 from sqlalchemy.sql.elements import BinaryExpression
-from sqlalchemy.orm import Query
-from sqlalchemy import and_, column, or_
+from sqlalchemy import and_, or_
 from sqlalchemy import asc
 from LibHanger.Models.fields import fields
 from LibHanger.Library.DataAccess.Base.uwDataAccess import uwDataAccess
@@ -15,9 +14,6 @@ from LibHanger.Library.uwDeclare import uwDeclare as en
 from LibHanger.Models.saJoin import saJoin
 from LibHanger.Models.saWhere import saWhere
 from LibHanger.Models.saOrderBy import saOrderBy
-from TestClass.log_race_id import log_race_id
-from TestClass.trn_race_id import trn_race_id
-from TestClass.trn_race_result import trn_race_result
 
 T = TypeVar('T')
 
